@@ -5,6 +5,7 @@
             "201": {"description": "Created"},
             "202": {"description": "No Content (accepted)"},
             "204": {"description": "No Content (success)"},
+            "302": {"description": "Found"},
             "400": {
                 "content": {
                     "application/json": {
@@ -93,7 +94,7 @@
                                 "unit": "s",
                                 "z_improvement": False,
                                 "z_regression": False,
-                                "z_score": "0.000000",
+                                "z_score": None,
                             },
                             "tags": {
                                 "compression": "snappy",
@@ -161,7 +162,7 @@
                                 "unit": "s",
                                 "z_improvement": False,
                                 "z_regression": False,
-                                "z_score": "0.000000",
+                                "z_score": None,
                             },
                             "tags": {
                                 "compression": "snappy",
@@ -230,7 +231,7 @@
                                     "unit": "s",
                                     "z_improvement": False,
                                     "z_regression": False,
-                                    "z_score": "0.000000",
+                                    "z_score": None,
                                 },
                                 "tags": {
                                     "compression": "snappy",
@@ -306,7 +307,7 @@
                             "baseline_run_id": "some-run-uuid-1",
                             "baseline_z_improvement": False,
                             "baseline_z_regression": False,
-                            "baseline_z_score": "0.000",
+                            "baseline_z_score": None,
                             "batch": "file-read",
                             "benchmark": "snappy, nyctaxi_sample, parquet, arrow",
                             "change": "0.000%",
@@ -316,7 +317,7 @@
                             "contender_run_id": "some-run-uuid-2",
                             "contender_z_improvement": False,
                             "contender_z_regression": False,
-                            "contender_z_score": "0.000",
+                            "contender_z_score": None,
                             "improvement": False,
                             "language": "Python",
                             "less_is_better": True,
@@ -348,7 +349,7 @@
                                 "baseline_run_id": "some-run-uuid-1",
                                 "baseline_z_improvement": False,
                                 "baseline_z_regression": False,
-                                "baseline_z_score": "0.000",
+                                "baseline_z_score": None,
                                 "batch": "file-read",
                                 "benchmark": "snappy, nyctaxi_sample, parquet, arrow",
                                 "change": "0.000%",
@@ -358,7 +359,7 @@
                                 "contender_run_id": "some-run-uuid-2",
                                 "contender_z_improvement": False,
                                 "contender_z_regression": False,
-                                "contender_z_score": "0.000",
+                                "contender_z_score": None,
                                 "improvement": False,
                                 "language": "Python",
                                 "less_is_better": True,
@@ -382,7 +383,7 @@
                                 "baseline_run_id": "some-run-uuid-1",
                                 "baseline_z_improvement": False,
                                 "baseline_z_regression": False,
-                                "baseline_z_score": "0.000",
+                                "baseline_z_score": None,
                                 "batch": "file-write",
                                 "benchmark": "snappy, nyctaxi_sample, parquet, arrow",
                                 "change": "0.000%",
@@ -392,7 +393,7 @@
                                 "contender_run_id": "some-run-uuid-2",
                                 "contender_z_improvement": False,
                                 "contender_z_regression": False,
-                                "contender_z_score": "0.000",
+                                "contender_z_score": None,
                                 "improvement": False,
                                 "language": "Python",
                                 "less_is_better": True,
@@ -741,7 +742,6 @@
                 "required": [
                     "batch_id",
                     "context",
-                    "github",
                     "machine_info",
                     "run_id",
                     "stats",
@@ -1116,6 +1116,23 @@
             }
         },
         "/api/docs.json": {},
+        "/api/google/": {
+            "get": {
+                "description": "Google SSO.",
+                "responses": {"302": {"$ref": "#/components/responses/302"}},
+                "tags": ["Authentication"],
+            }
+        },
+        "/api/google/callback": {
+            "get": {
+                "description": "Google SSO callback.",
+                "responses": {
+                    "302": {"$ref": "#/components/responses/302"},
+                    "400": {"$ref": "#/components/responses/400"},
+                },
+                "tags": ["Authentication"],
+            }
+        },
         "/api/history/{benchmark_id}/": {
             "get": {
                 "description": "Get benchmark history.",
