@@ -7,10 +7,12 @@ from ...api._examples import _api_benchmark_entity
 from ...entities._entity import NotFound
 from ...entities.distribution import Distribution
 from ...entities.summary import Summary
-from ...tests.api import _asserts
-from ...tests.api import _fixtures
+from ...tests.api import _asserts, _fixtures
 from ...tests.helpers import _uuid
 
+ARROW_REPO = "https://github.com/apache/arrow"
+CONBENCH_REPO = "https://github.com/ursacomputing/conbench"
+
 
 def _expected_entity(summary):
     return _api_benchmark_entity(
@@ -306,7 +308,6 @@ class TestBenchmarkPost(_asserts.PostEnforcer):
         "stats",
         "tags",
         "context",
-        "github",
     ]
 
     def test_create_benchmark(self, client):
@@ -360,6 +361,159 @@ class TestBenchmarkPost(_asserts.PostEnforcer):
         }
         self.assert_400_bad_request(response, message)
 
+    def _assert_none_commit(self, response):
+        new_id = response.json["id"]
+        summary = Summary.one(id=new_id)
+        assert summary.run.commit.sha == ""
+        assert summary.run.commit.repository == ""
+        assert summary.run.commit.parent is None
+        return summary, new_id
+
+    def test_create_no_commit_context(self, client):
+        self.authenticate(client)
+        data = copy.deepcopy(self.valid_payload)
+        data["run_id"] = _uuid()
+        del data["github"]
+
+        # create benchmark without commit context
+        response = client.post("/api/benchmarks/", json=data)
+        summary, new_id = self._assert_none_commit(response)
+        location = "http://localhost/api/benchmarks/%s/" % new_id
+        self.assert_201_created(response, _expected_entity(summary), location)
+
+        # create another benchmark without commit context
+        # (test duplicate key duplicate key -- commit_index)
+        response = client.post("/api/benchmarks/", json=data)
+        summary, new_id = self._assert_none_commit(response)
+        location = "http://localhost/api/benchmarks/%s/" % new_id
+        self.assert_201_created(response, _expected_entity(summary), location)
+
+    def test_create_empty_commit_context(self, client):
+        self.authenticate(client)
+        data = copy.deepcopy(self.valid_payload)
+        data["run_id"] = _uuid()
+        data["github"]["commit"] = ""
+        data["github"]["repository"] = ""
+
+        # create benchmark without commit context
+        response = client.post("/api/benchmarks/", json=data)
+        summary, new_id = self._assert_none_commit(response)
+        location = "http://localhost/api/benchmarks/%s/" % new_id
+        self.assert_201_created(response, _expected_entity(summary), location)
+
+        # create another benchmark without commit context
+        # (test duplicate key duplicate key -- commit_index)
+        response = client.post("/api/benchmarks/", json=data)
+        summary, new_id = self._assert_none_commit(response)
+        location = "http://localhost/api/benchmarks/%s/" % new_id
+        self.assert_201_created(response, _expected_entity(summary), location)
+
+    def test_create_unknown_commit_context(self, client):
+        self.authenticate(client)
+        data = copy.deepcopy(self.valid_payload)
+        data["run_id"] = _uuid()
+        data["github"]["commit"] = "unknown commit"
+        data["github"]["repository"] = ARROW_REPO
+
+        # create benchmark with unknown commit context
+        response = client.post("/api/benchmarks/", json=data)
+        new_id = response.json["id"]
+        summary = Summary.one(id=new_id)
+        assert summary.run.commit.sha == "unknown commit"
+        assert summary.run.commit.repository == ARROW_REPO
+        assert summary.run.commit.parent is None
+        location = "http://localhost/api/benchmarks/%s/" % new_id
+        self.assert_201_created(response, _expected_entity(summary), location)
+
+        # create another benchmark with unknown commit context
+        # (test duplicate key duplicate key -- commit_index)
+        response = client.post("/api/benchmarks/", json=data)
+        new_id = response.json["id"]
+        summary = Summary.one(id=new_id)
+        assert summary.run.commit.sha == "unknown commit"
+        assert summary.run.commit.repository == ARROW_REPO
+        assert summary.run.commit.parent is None
+        location = "http://localhost/api/benchmarks/%s/" % new_id
+        self.assert_201_created(response, _expected_entity(summary), location)
+
+    def test_create_different_git_repo_format(self, client):
+        self.authenticate(client)
+        data = copy.deepcopy(self.valid_payload)
+        data["run_id"] = _uuid()
+        data["github"]["commit"] = "testing repository with git@g"
+        data["github"]["repository"] = "git@github.com:apache/arrow"
+
+        response = client.post("/api/benchmarks/", json=data)
+        new_id = response.json["id"]
+        summary = Summary.one(id=new_id)
+        assert summary.run.commit.sha == "testing repository with git@g"
+        assert summary.run.commit.repository == ARROW_REPO
+        assert summary.run.commit.parent is None
+        location = "http://localhost/api/benchmarks/%s/" % new_id
+        self.assert_201_created(response, _expected_entity(summary), location)
+
+    def test_create_repo_not_full_url(self, client):
+        self.authenticate(client)
+        data = copy.deepcopy(self.valid_payload)
+        data["run_id"] = _uuid()
+        data["github"]["commit"] = "testing repository with just org/repo"
+        data["github"]["repository"] = "apache/arrow"
+
+        response = client.post("/api/benchmarks/", json=data)
+        new_id = response.json["id"]
+        summary = Summary.one(id=new_id)
+        assert summary.run.commit.sha == "testing repository with just org/repo"
+        assert summary.run.commit.repository == ARROW_REPO
+        assert summary.run.commit.parent is None
+        location = "http://localhost/api/benchmarks/%s/" % new_id
+        self.assert_201_created(response, _expected_entity(summary), location)
+
+    def test_create_allow_just_repository(self, client):
+        self.authenticate(client)
+        data = copy.deepcopy(self.valid_payload)
+        data["run_id"] = _uuid()
+        data["github"]["commit"] = ""
+        data["github"]["repository"] = ARROW_REPO
+
+        response = client.post("/api/benchmarks/", json=data)
+        new_id = response.json["id"]
+        summary = Summary.one(id=new_id)
+        assert summary.run.commit.sha == ""
+        assert summary.run.commit.repository == ARROW_REPO
+        assert summary.run.commit.parent is None
+        location = "http://localhost/api/benchmarks/%s/" % new_id
+        self.assert_201_created(response, _expected_entity(summary), location)
+
+        # And again with a different repository with an empty sha
+        data["run_id"] = _uuid()
+        data["github"]["commit"] = ""
+        data["github"]["repository"] = CONBENCH_REPO
+
+        response = client.post("/api/benchmarks/", json=data)
+        new_id = response.json["id"]
+        summary = Summary.one(id=new_id)
+        assert summary.run.commit.sha == ""
+        assert summary.run.commit.repository == CONBENCH_REPO
+        assert summary.run.commit.parent is None
+        location = "http://localhost/api/benchmarks/%s/" % new_id
+        self.assert_201_created(response, _expected_entity(summary), location)
+
+    def test_create_allow_just_sha(self, client):
+        self.authenticate(client)
+        data = copy.deepcopy(self.valid_payload)
+        data["run_id"] = _uuid()
+        data["github"]["commit"] = "something something"
+        data["github"]["repository"] = ""
+
+        response = client.post("/api/benchmarks/", json=data)
+        new_id = response.json["id"]
+        summary = Summary.one(id=new_id)
+        assert summary.run.commit.sha == "something something"
+        assert summary.run.commit.repository == ""
+        assert summary.run.commit.parent is None
+        location = "http://localhost/api/benchmarks/%s/" % new_id
+        self.assert_201_created(response, _expected_entity(summary), location)
+
     def test_create_benchmark_distribution(self, client):
         self.authenticate(client)
         data = copy.deepcopy(self.valid_payload)
