@@ -5,7 +5,6 @@ import statistics
 
 from ...entities.commit import Commit
 from ...entities.distribution import (
-    Distribution,
     get_commit_index,
     get_commits_up,
     get_distribution,
@@ -17,14 +16,13 @@ from ...runner import Conbench
 from ...tests.api import _fixtures
 from ...tests.helpers import _uuid
 
-
-REPO = "arrow"
+REPO = "https://github.com/org/something"
 MACHINE = "diana-2-4-17179869184"
 
 COMMIT_INDEX = """WITH ordered_commits AS 
 (SELECT commit.id AS id, commit.sha AS sha, commit.timestamp AS timestamp 
 FROM commit 
-WHERE commit.repository = :repository_1 ORDER BY commit.timestamp DESC)
+WHERE commit.repository = :repository_1 AND commit.timestamp IS NOT NULL ORDER BY commit.timestamp DESC)
  SELECT ordered_commits.id, ordered_commits.sha, ordered_commits.timestamp, row_number() OVER () AS row_number 
 FROM ordered_commits"""  # noqa
 
@@ -32,7 +30,7 @@ FROM ordered_commits"""  # noqa
 ROW_NUMBER = """WITH ordered_commits AS 
 (SELECT commit.id AS id, commit.sha AS sha, commit.timestamp AS timestamp 
 FROM commit 
-WHERE commit.repository = :repository_1 ORDER BY commit.timestamp DESC)
+WHERE commit.repository = :repository_1 AND commit.timestamp IS NOT NULL ORDER BY commit.timestamp DESC)
  SELECT commit_index.row_number 
 FROM (SELECT ordered_commits.id AS id, ordered_commits.sha AS sha, ordered_commits.timestamp AS timestamp, row_number() OVER () AS row_number 
 FROM ordered_commits) AS commit_index 
@@ -42,7 +40,7 @@ WHERE commit_index.sha = :sha_1"""  # noqa
 COMMITS_UP = """WITH ordered_commits AS 
 (SELECT commit.id AS id, commit.sha AS sha, commit.timestamp AS timestamp 
 FROM commit 
-WHERE commit.repository = :repository_1 ORDER BY commit.timestamp DESC)
+WHERE commit.repository = :repository_1 AND commit.timestamp IS NOT NULL ORDER BY commit.timestamp DESC)
  SELECT commit_index.id, commit_index.sha, commit_index.timestamp, commit_index.row_number 
 FROM (SELECT ordered_commits.id AS id, ordered_commits.sha AS sha, ordered_commits.timestamp AS timestamp, row_number() OVER () AS row_number 
 FROM ordered_commits) AS commit_index 
@@ -56,7 +54,7 @@ WHERE commit_index.sha = :sha_1)
 DISTRIBUTION = """WITH ordered_commits AS 
 (SELECT commit.id AS id, commit.sha AS sha, commit.timestamp AS timestamp 
 FROM commit 
-WHERE commit.repository = :repository_1 ORDER BY commit.timestamp DESC)
+WHERE commit.repository = :repository_1 AND commit.timestamp IS NOT NULL ORDER BY commit.timestamp DESC)
  SELECT text(:text_1) AS case_id, text(:text_2) AS context_id, text(:text_3) AS commit_id, concat(machine.name, :concat_1, machine.cpu_core_count, :concat_2, machine.cpu_thread_count, :concat_3, machine.memory_bytes) AS hash, max(summary.unit) AS unit, avg(summary.mean) AS mean_mean, stddev(summary.mean) AS mean_sd, avg(summary.min) AS min_mean, stddev(summary.min) AS min_sd, avg(summary.max) AS max_mean, stddev(summary.max) AS max_sd, avg(summary.median) AS median_mean, stddev(summary.median) AS median_sd, min(commits_up.timestamp) AS first_timestamp, max(commits_up.timestamp) AS last_timestamp, count(summary.mean) AS observations 
 FROM summary JOIN run ON run.id = summary.run_id JOIN machine ON machine.id = run.machine_id JOIN (SELECT commit_index.id AS id, commit_index.sha AS sha, commit_index.timestamp AS timestamp, commit_index.row_number AS row_number 
 FROM (SELECT ordered_commits.id AS id, ordered_commits.sha AS sha, ordered_commits.timestamp AS timestamp, row_number() OVER () AS row_number 
@@ -256,8 +254,6 @@ def test_distribution():
     assert summary_1.run.machine_id == summary_4.run.machine_id
     assert summary_1.run.machine_id == summary_5.run.machine_id
 
-    assert Distribution.count() >= 7
-
     # ----- get_commit_index
 
     expected = [
@@ -416,15 +412,15 @@ def test_distribution():
 
     # first commit, no distribution history
     set_z_scores([summary_1])
-    assert summary_1.z_score == 0
+    assert summary_1.z_score is None
 
     # second commit, no change
     set_z_scores([summary_2])
-    assert summary_2.z_score == 0
+    assert summary_2.z_score is None
 
     # third commit, got better, but distribution stdev was 0
     set_z_scores([summary_3])
-    assert summary_3.z_score == 0
+    assert summary_3.z_score is None
 
     # forth commit, stayed about the same (but still better)
     set_z_scores([summary_4])
@@ -436,11 +432,11 @@ def test_distribution():
 
     # n/a different repo, no distribution history
     set_z_scores([summary_b])
-    assert summary_b.z_score == 0
+    assert summary_b.z_score is None
 
     # n/a different case, no distribution history
     set_z_scores([summary_x])
-    assert summary_x.z_score == 0
+    assert summary_x.z_score is None
 
 
 def test_distribution_multiple_runs_same_commit():
@@ -533,9 +529,9 @@ def test_distribution_multiple_runs_same_commit():
 
     # before
     set_z_scores([summary_1])
-    assert summary_1.z_score == 0
+    assert summary_1.z_score is None
     set_z_scores([summary_2])
-    assert summary_2.z_score == 0
+    assert summary_2.z_score is None
     set_z_scores([summary_3])
     Z_SCORE_UP_DECIMAL = decimal.Decimal(_fixtures.Z_SCORE_UP)
     assert round(summary_3.z_score, 10) == -1 * round(Z_SCORE_UP_DECIMAL, 10)
@@ -543,13 +539,13 @@ def test_distribution_multiple_runs_same_commit():
     # re-run commit 2
     summary_4 = create_benchmark_summary([0, 1, 2], commit_2, name=name)
     set_z_scores([summary_4])
-    assert summary_4.z_score == 0
+    assert summary_4.z_score is None
 
     # after, summary_3 z-score changes with more info
     set_z_scores([summary_1])
-    assert summary_1.z_score == 0
+    assert summary_1.z_score is None
     set_z_scores([summary_2])
-    assert summary_2.z_score == 0
+    assert summary_2.z_score is None
     set_z_scores([summary_3])
     Z_SCORE_UP_DECIMAL = decimal.Decimal("18.0000000000")
     assert round(summary_3.z_score, 10) == -1 * round(Z_SCORE_UP_DECIMAL, 10)
